@@ -101,7 +101,7 @@ class SOAPHandlerBase():
     def __init__(self, *args, **kwargs):
         self.__dict__.update(kwargs)
     
-    def _send_request(self, verb: VERBMAP, url: str, data, headers, log=False):
+    def _send_request(self, verb: VERBMAP, url: str, data, headers):
         """
         Sends the request to the server.
         """
@@ -112,22 +112,20 @@ class SOAPHandlerBase():
         if headers is None and (self.headers is {} or self.headers is None):
             raise exceptions.HeaderNotFound
         
-        if log:
-            req_log = SOAPRequestLogger.objects.create(
-                method=verb.value,
-                url=url or self.url,
-                headers=str(headers or self.headers),
-                body=data,            
-            )
+        req_log = SOAPRequestLogger.objects.create(
+            method=verb.value,
+            url=url or self.url,
+            headers=str(headers or self.headers),
+            body=data,            
+        )
         
         r = requests.post(url, data=data, headers=headers)
         response = self._receive_response(req_log, r, log)
         
-        if log:
-            req_log.request_time_ms = (
-                datetime.now(timezone.utc) - req_log.date_sent
-            ).microseconds
-            req_log.save()
+        req_log.request_time_ms = (
+            datetime.now(timezone.utc) - req_log.date_sent
+        ).microseconds
+        req_log.save()
 
         return response
     
@@ -175,20 +173,19 @@ class SOAPHandlerBase():
         
         return response.status_code
     
-    def _receive_response(self, request_logger, response, log=False) -> SoapResult:
+    def _receive_response(self, request_logger, response) -> SoapResult:
         """
         Updates the SOAPResponseLogger with response info and
         parses the response to a SOAP Result.
         """
         status_code = self._handle_status_codes(response)
         
-        if log:
-            SOAPResponseLogger.objects.create(
-                request_id=request_logger,
-                status=status_code,
-                headers=str(response.headers),
-                body=str(response.content),
-            )
+        SOAPResponseLogger.objects.create(
+            request_id=request_logger,
+            status=status_code,
+            headers=str(response.headers),
+            body=str(response.content),
+        )
 
         result = SoapResult(response.text, response.status_code)
 
@@ -249,7 +246,6 @@ class SOAPHandlerBase():
             envelope_attributes.get('url') or self.url,
             data=payload,
             headers=self.headers,
-            log=False
         )
         return result
     
